@@ -16,7 +16,7 @@ import threading
 import time
 
 from types import ModuleType
-from typing import Iterable, Optional
+from collections.abc import Iterable
 
 from flaky import flaky
 import pytest
@@ -30,6 +30,7 @@ from coverage.misc import import_local_file
 
 from tests import testenv
 from tests.coveragetest import CoverageTest
+from tests.helpers import flaky_method
 
 
 # These libraries aren't always available, we'll skip tests if they aren't.
@@ -175,7 +176,7 @@ SIMPLE = """
     """
 
 
-def cant_trace_msg(concurrency: str, the_module: Optional[ModuleType]) -> Optional[str]:
+def cant_trace_msg(concurrency: str, the_module: ModuleType | None) -> str | None:
     """What might coverage.py say about a concurrency setting and imported module?"""
     # In the concurrency choices, "multiprocessing" doesn't count, so remove it.
     if "multiprocessing" in concurrency:
@@ -208,7 +209,7 @@ class ConcurrencyTest(CoverageTest):
         code: str,
         concurrency: str,
         the_module: ModuleType,
-        expected_out: Optional[str] = None,
+        expected_out: str | None = None,
     ) -> None:
         """Run some concurrency testing code and see that it was all covered.
 
@@ -317,6 +318,7 @@ class ConcurrencyTest(CoverageTest):
             """
         self.try_some_code(BUG_330, "eventlet", eventlet, "0\n")
 
+    @flaky_method(max_runs=3)   # Sometimes a test fails due to inherent randomness. Try more times.
     def test_threads_with_gevent(self) -> None:
         self.make_file("both.py", """\
             import queue
@@ -457,7 +459,7 @@ class MultiprocessingTest(CoverageTest):
     def try_multiprocessing_code(
         self,
         code: str,
-        expected_out: Optional[str],
+        expected_out: str | None,
         the_module: ModuleType,
         nprocs: int,
         start_method: str,
@@ -490,7 +492,7 @@ class MultiprocessingTest(CoverageTest):
             assert all(
                 re.fullmatch(
                     r"(Combined data file|Skipping duplicate data) \.coverage\..*\.\d+\.X\w{6}x",
-                    line
+                    line,
                 )
                 for line in out_lines
             )
@@ -730,7 +732,7 @@ class SigtermTest(CoverageTest):
             [run]
             parallel = True
             concurrency = multiprocessing
-            """ + ("sigterm = true" if sigterm else "")
+            """ + ("sigterm = true" if sigterm else ""),
             )
         out = self.run_command("coverage run clobbered.py")
         # Under Linux, things go wrong. Does that matter?
