@@ -23,7 +23,7 @@ class TestCoverageTest(CoverageTest):
             a = 1
             b = 2
             """,
-            [1,2]
+            [1,2],
         )
         # You can provide a list of possible statement matches.
         self.check_coverage("""\
@@ -41,15 +41,6 @@ class TestCoverageTest(CoverageTest):
             [1,2,3],
             missing="3",
         )
-        # You can specify a list of possible missing lines.
-        self.check_coverage("""\
-            a = 1
-            if a == 2:
-                a = 3
-            """,
-            [1,2,3],
-            missing=("47-49", "3", "100,102")
-        )
 
     def test_failed_coverage(self) -> None:
         # If the lines are wrong, the message shows right and wrong.
@@ -58,7 +49,7 @@ class TestCoverageTest(CoverageTest):
                 a = 1
                 b = 2
                 """,
-                [1]
+                [1],
             )
         # If the list of lines possibilities is wrong, the msg shows right.
         msg = r"None of the lines choices matched \[1, 2]"
@@ -67,7 +58,7 @@ class TestCoverageTest(CoverageTest):
                 a = 1
                 b = 2
                 """,
-                ([1], [2])
+                ([1], [2]),
             )
         # If the missing lines are wrong, the message shows right and wrong.
         with pytest.raises(AssertionError, match=r"'3' != '37'"):
@@ -79,17 +70,6 @@ class TestCoverageTest(CoverageTest):
                 [1,2,3],
                 missing="37",
             )
-        # If the missing lines possibilities are wrong, the msg shows right.
-        msg = r"None of the missing choices matched '3'"
-        with pytest.raises(AssertionError, match=msg):
-            self.check_coverage("""\
-                a = 1
-                if a == 2:
-                    a = 3
-                """,
-                [1,2,3],
-                missing=("37", "4-10"),
-            )
 
     def test_exceptions_really_fail(self) -> None:
         # An assert in the checked code will really raise up to us.
@@ -97,7 +77,7 @@ class TestCoverageTest(CoverageTest):
             self.check_coverage("""\
                 a = 1
                 assert a == 99, "This is bad"
-                """
+                """,
             )
         # Other exceptions too.
         with pytest.raises(ZeroDivisionError, match="division"):
@@ -105,7 +85,7 @@ class TestCoverageTest(CoverageTest):
                 a = 1
                 assert a == 1, "This is good"
                 a/0
-                """
+                """,
             )
 
 
@@ -121,7 +101,7 @@ class BasicCoverageTest(CoverageTest):
             # Nothing here
             d = 6
             """,
-            [1,2,4,6], report="4 0 0 0 100%"
+            [1,2,4,6], report="4 0 0 0 100%",
         )
 
     def test_indentation_wackiness(self) -> None:
@@ -131,7 +111,7 @@ class BasicCoverageTest(CoverageTest):
             if not sys.path:
                 a = 1
                 """,    # indented last line
-            [1,2,3], "3"
+            [1,2,3], "3",
         )
 
     def test_multiline_initializer(self) -> None:
@@ -144,7 +124,7 @@ class BasicCoverageTest(CoverageTest):
 
             e = { 'foo': 1, 'bar': 2 }
             """,
-            [1,7], ""
+            [1,7], "",
         )
 
     def test_list_comprehension(self) -> None:
@@ -155,7 +135,7 @@ class BasicCoverageTest(CoverageTest):
                 ]
             assert l == [12, 14, 16, 18]
             """,
-            [1,5], ""
+            [1,5], "",
         )
 
 
@@ -170,21 +150,21 @@ class SimpleStatementTest(CoverageTest):
             12
             23
             """,
-            ([1,2],[2]), ""
+            ([1,2],[2]), "",
         )
         self.check_coverage("""\
             12
             23
             a = 3
             """,
-            ([1,2,3],[3]), ""
+            ([1,2,3],[3]), "",
         )
         self.check_coverage("""\
             1 + 2
             1 + \\
                 2
             """,
-            ([1,2], [2]), ""
+            ([1,2], [2]), "",
         )
         self.check_coverage("""\
             1 + 2
@@ -192,7 +172,7 @@ class SimpleStatementTest(CoverageTest):
                 2
             a = 4
             """,
-            ([1,2,4], [4]), ""
+            ([1,2,4], [4]), "",
         )
 
     def test_assert(self) -> None:
@@ -205,7 +185,7 @@ class SimpleStatementTest(CoverageTest):
                 2), \\
                 'something is amiss'
             """,
-            [1,2,4,5], ""
+            [1,2,4,5], "",
         )
 
     def test_assignment(self) -> None:
@@ -217,7 +197,7 @@ class SimpleStatementTest(CoverageTest):
             c = \\
                 1
             """,
-            [1,2,4], ""
+            [1,2,4], "",
         )
 
     def test_assign_tuple(self) -> None:
@@ -226,7 +206,7 @@ class SimpleStatementTest(CoverageTest):
             a,b,c = 7,8,9
             assert a == 7 and b == 8 and c == 9
             """,
-            [1,2,3], ""
+            [1,2,3], "",
         )
 
     def test_more_assignments(self) -> None:
@@ -242,7 +222,7 @@ class SimpleStatementTest(CoverageTest):
             ] = \\
                 9
             """,
-            [1, 2, 3], ""
+            [1, 2, 3], "",
         )
 
     def test_attribute_assignment(self) -> None:
@@ -256,7 +236,7 @@ class SimpleStatementTest(CoverageTest):
             o.foo = \\
                 1
             """,
-            [1,2,3,4,6], ""
+            [1,2,3,4,6], "",
         )
 
     def test_list_of_attribute_assignment(self) -> None:
@@ -271,7 +251,7 @@ class SimpleStatementTest(CoverageTest):
                 1, \\
                 2
             """,
-            [1,2,3,4,7], ""
+            [1,2,3,4,7], "",
         )
 
     def test_augmented_assignment(self) -> None:
@@ -283,7 +263,7 @@ class SimpleStatementTest(CoverageTest):
             a += \\
                 1
             """,
-            [1,2,3,5], ""
+            [1,2,3,5], "",
         )
 
     def test_triple_string_stuff(self) -> None:
@@ -306,7 +286,7 @@ class SimpleStatementTest(CoverageTest):
                 lines.
                 ''')
             """,
-            [1,5,11], ""
+            [1,5,11], "",
         )
 
     def test_pass(self) -> None:
@@ -316,14 +296,14 @@ class SimpleStatementTest(CoverageTest):
             if 1==1:
                 pass
             """,
-            [1,2], ""
+            [1,2], "",
         )
         self.check_coverage("""\
             def foo():
                 pass
             foo()
             """,
-            [1,2,3], ""
+            [1,2,3], "",
         )
         self.check_coverage("""\
             def foo():
@@ -331,7 +311,7 @@ class SimpleStatementTest(CoverageTest):
                 pass
             foo()
             """,
-            ([1,3,4], [1,4]), ""
+            ([1,3,4], [1,4]), "",
         )
         self.check_coverage("""\
             class Foo:
@@ -339,7 +319,7 @@ class SimpleStatementTest(CoverageTest):
                     pass
             Foo().foo()
             """,
-            [1,2,3,4], ""
+            [1,2,3,4], "",
         )
         self.check_coverage("""\
             class Foo:
@@ -348,7 +328,7 @@ class SimpleStatementTest(CoverageTest):
                     pass
             Foo().foo()
             """,
-            ([1,2,4,5], [1,2,5]), ""
+            ([1,2,4,5], [1,2,5]), "",
         )
 
     def test_del(self) -> None:
@@ -363,7 +343,7 @@ class SimpleStatementTest(CoverageTest):
                 d['e']
             assert(len(d.keys()) == 0)
             """,
-            [1,2,3,6,9], ""
+            [1,2,3,6,9], "",
         )
 
     def test_raise(self) -> None:
@@ -375,7 +355,7 @@ class SimpleStatementTest(CoverageTest):
             except:
                 pass
             """,
-            [1,2,5,6], ""
+            [1,2,5,6], "",
         )
 
     def test_raise_followed_by_statement(self) -> None:
@@ -392,7 +372,7 @@ class SimpleStatementTest(CoverageTest):
             except:
                 pass
             """,
-            lines=lines, missing=missing
+            lines=lines, missing=missing,
         )
 
     def test_return(self) -> None:
@@ -404,7 +384,7 @@ class SimpleStatementTest(CoverageTest):
             x = fn()
             assert(x == 1)
             """,
-            [1,2,3,5,6], ""
+            [1,2,3,5,6], "",
         )
         self.check_coverage("""\
             def fn():
@@ -416,7 +396,7 @@ class SimpleStatementTest(CoverageTest):
             x = fn()
             assert(x == 2)
             """,
-            [1,2,3,7,8], ""
+            [1,2,3,7,8], "",
         )
         self.check_coverage("""\
             def fn():
@@ -428,7 +408,7 @@ class SimpleStatementTest(CoverageTest):
             x,y,z = fn()
             assert x == 1 and y == 2 and z == 3
             """,
-            [1,2,3,7,8], ""
+            [1,2,3,7,8], "",
         )
 
     def test_return_followed_by_statement(self) -> None:
@@ -462,7 +442,7 @@ class SimpleStatementTest(CoverageTest):
             a,b,c = gen()
             assert a == 1 and b == 9 and c == (1,2)
             """,
-            [1,2,3,6,8,9], ""
+            [1,2,3,6,8,9], "",
         )
 
     def test_break(self) -> None:
@@ -480,7 +460,7 @@ class SimpleStatementTest(CoverageTest):
                 a = 4
             assert a == 2
             """,
-            lines=lines, missing=missing
+            lines=lines, missing=missing,
         )
 
     def test_continue(self) -> None:
@@ -498,10 +478,11 @@ class SimpleStatementTest(CoverageTest):
                 a = 4
             assert a == 11
             """,
-            lines=lines, missing=missing
+            lines=lines, missing=missing,
         )
 
     def test_strange_unexecuted_continue(self) -> None:
+        # This used to be true, but no longer is:
         # Peephole optimization of jumps to jumps can mean that some statements
         # never hit the line tracer.  The behavior is different in different
         # versions of Python, so be careful when running this test.
@@ -529,7 +510,7 @@ class SimpleStatementTest(CoverageTest):
             assert a == 33 and b == 50 and c == 50
             """,
             lines=[1,2,3,4,5,6,8,9,10, 12,13,14,15,16,17,19,20,21],
-            missing=["", "6"],
+            missing="",
         )
 
     def test_import(self) -> None:
@@ -538,7 +519,7 @@ class SimpleStatementTest(CoverageTest):
             from sys import path
             a = 1
             """,
-            [1,2,3], ""
+            [1,2,3], "",
         )
         self.check_coverage("""\
             import string
@@ -546,7 +527,7 @@ class SimpleStatementTest(CoverageTest):
                 from sys import path
             a = 1
             """,
-            [1,2,3,4], "3"
+            [1,2,3,4], "3",
         )
         self.check_coverage("""\
             import string, \\
@@ -556,34 +537,34 @@ class SimpleStatementTest(CoverageTest):
                 stdout
             a = 1
             """,
-            [1,4,6], ""
+            [1,4,6], "",
         )
         self.check_coverage("""\
             import sys, sys as s
             assert s.path == sys.path
             """,
-            [1,2], ""
+            [1,2], "",
         )
         self.check_coverage("""\
             import sys, \\
                 sys as s
             assert s.path == sys.path
             """,
-            [1,3], ""
+            [1,3], "",
         )
         self.check_coverage("""\
             from sys import path, \\
                 path as p
             assert p == path
             """,
-            [1,3], ""
+            [1,3], "",
         )
         self.check_coverage("""\
             from sys import \\
                 *
             assert len(path) > 0
             """,
-            [1,3], ""
+            [1,3], "",
         )
 
     def test_global(self) -> None:
@@ -597,7 +578,7 @@ class SimpleStatementTest(CoverageTest):
             fn()
             assert g == 2 and h == 2 and i == 2
             """,
-            [1,2,6,7,8], ""
+            [1,2,6,7,8], "",
         )
         self.check_coverage("""\
             g = h = i = 1
@@ -606,7 +587,7 @@ class SimpleStatementTest(CoverageTest):
             fn()
             assert g == 2 and h == 1 and i == 1
             """,
-            [1,2,3,4,5], ""
+            [1,2,3,4,5], "",
         )
 
     def test_exec(self) -> None:
@@ -618,7 +599,7 @@ class SimpleStatementTest(CoverageTest):
                 "2")
             assert a == 2 and b == 2 and c == 2
             """,
-            [1,2,3,6], ""
+            [1,2,3,6], "",
         )
         self.check_coverage("""\
             vars = {'a': 1, 'b': 1, 'c': 1}
@@ -628,7 +609,7 @@ class SimpleStatementTest(CoverageTest):
                 "2", vars)
             assert vars['a'] == 2 and vars['b'] == 2 and vars['c'] == 2
             """,
-            [1,2,3,6], ""
+            [1,2,3,6], "",
         )
         self.check_coverage("""\
             globs = {}
@@ -639,7 +620,7 @@ class SimpleStatementTest(CoverageTest):
                 "2", globs, locs)
             assert locs['a'] == 2 and locs['b'] == 2 and locs['c'] == 2
             """,
-            [1,2,3,4,7], ""
+            [1,2,3,4,7], "",
         )
 
     def test_extra_doc_string(self) -> None:
@@ -671,7 +652,7 @@ class SimpleStatementTest(CoverageTest):
             a = 2
             b = 3
             """,
-            [2, 3]
+            [2, 3],
         )
 
     def test_module_docstring(self) -> None:
@@ -680,16 +661,15 @@ class SimpleStatementTest(CoverageTest):
             a = 2
             b = 3
             """,
-            [2, 3]
+            [2, 3],
         )
-        lines = [2, 3, 4]
         self.check_coverage("""\
-            # Start with a comment, because it changes the behavior(!?)
+            # Start with a comment, even though it doesn't change the behavior.
             '''I am a module docstring.'''
             a = 3
             b = 4
             """,
-            lines
+            [3, 4],
         )
 
 
@@ -704,7 +684,7 @@ class CompoundStatementTest(CoverageTest):
 
             assert (a,b,c,d,e) == (1,2,3,4,5)
             """,
-            [1,2,3,5], ""
+            [1,2,3,5], "",
         )
 
     def test_if(self) -> None:
@@ -718,7 +698,7 @@ class CompoundStatementTest(CoverageTest):
                 x = 7
             assert x == 7
             """,
-            [1,2,3,4,5,7,8], ""
+            [1,2,3,4,5,7,8], "",
         )
         self.check_coverage("""\
             a = 1
@@ -728,7 +708,7 @@ class CompoundStatementTest(CoverageTest):
                 y = 5
             assert x == 3
             """,
-            [1,2,3,5,6], "5"
+            [1,2,3,5,6], "5",
         )
         self.check_coverage("""\
             a = 1
@@ -738,7 +718,7 @@ class CompoundStatementTest(CoverageTest):
                 y = 5
             assert y == 5
             """,
-            [1,2,3,5,6], "3"
+            [1,2,3,5,6], "3",
         )
         self.check_coverage("""\
             a = 1; b = 2
@@ -751,7 +731,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 8
             assert x == 4
             """,
-            [1,2,3,4,6,8,9], "6-8"
+            [1,2,3,4,6,8,9], "6-8",
         )
 
     def test_elif(self) -> None:
@@ -830,7 +810,7 @@ class CompoundStatementTest(CoverageTest):
                 else:
                     x = 13
             """,
-            [1,2,3,4,5,6,7,8,9,10,11,13], "2-13"
+            [1,2,3,4,5,6,7,8,9,10,11,13], "2-13",
         )
 
     def test_split_if(self) -> None:
@@ -846,7 +826,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert x == 3
             """,
-            [1,2,4,5,7,9,10], "5-9"
+            [1,2,4,5,7,9,10], "5-9",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -860,7 +840,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert y == 5
             """,
-            [1,2,4,5,7,9,10], "4, 9"
+            [1,2,4,5,7,9,10], "4, 9",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -874,7 +854,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert z == 7
             """,
-            [1,2,4,5,7,9,10], "4, 7"
+            [1,2,4,5,7,9,10], "4, 7",
         )
 
     def test_pathological_split_if(self) -> None:
@@ -892,7 +872,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert x == 3
             """,
-            [1,2,5,6,9,11,12], "6-11"
+            [1,2,5,6,9,11,12], "6-11",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -908,7 +888,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert y == 5
             """,
-            [1,2,5,6,9,11,12], "5, 11"
+            [1,2,5,6,9,11,12], "5, 11",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -924,7 +904,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert z == 7
             """,
-            [1,2,5,6,9,11,12], "5, 9"
+            [1,2,5,6,9,11,12], "5, 9",
         )
 
     def test_absurd_split_if(self) -> None:
@@ -940,7 +920,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert x == 3
             """,
-            [1,2,4,5,7,9,10], "5-9"
+            [1,2,4,5,7,9,10], "5-9",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -954,7 +934,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert y == 5
             """,
-            [1,2,4,5,7,9,10], "4, 9"
+            [1,2,4,5,7,9,10], "4, 9",
         )
         self.check_coverage("""\
             a = 1; b = 2; c = 3;
@@ -968,7 +948,7 @@ class CompoundStatementTest(CoverageTest):
                 z = 7
             assert z == 7
             """,
-            [1,2,4,5,7,9,10], "4, 7"
+            [1,2,4,5,7,9,10], "4, 7",
         )
 
     def test_constant_if(self) -> None:
@@ -993,7 +973,7 @@ class CompoundStatementTest(CoverageTest):
                 a -= 1
             assert a == 0 and b == 3
             """,
-            [1,2,3,4,5], ""
+            [1,2,3,4,5], "",
         )
         self.check_coverage("""\
             a = 3; b = 0
@@ -1002,7 +982,7 @@ class CompoundStatementTest(CoverageTest):
                 break
             assert a == 3 and b == 1
             """,
-            [1,2,3,4,5], ""
+            [1,2,3,4,5], "",
         )
 
     def test_while_else(self) -> None:
@@ -1016,7 +996,7 @@ class CompoundStatementTest(CoverageTest):
                 b = 99
             assert a == 0 and b == 99
             """,
-            [1,2,3,4,6,7], ""
+            [1,2,3,4,6,7], "",
         )
         # Don't take the else branch.
         self.check_coverage("""\
@@ -1029,7 +1009,7 @@ class CompoundStatementTest(CoverageTest):
                 b = 99
             assert a == 2 and b == 1
             """,
-            [1,2,3,4,5,7,8], "7"
+            [1,2,3,4,5,7,8], "7",
         )
 
     def test_split_while(self) -> None:
@@ -1041,7 +1021,7 @@ class CompoundStatementTest(CoverageTest):
                 a -= 1
             assert a == 0 and b == 3
             """,
-            [1,2,4,5,6], ""
+            [1,2,4,5,6], "",
         )
         self.check_coverage("""\
             a = 3; b = 0
@@ -1052,7 +1032,7 @@ class CompoundStatementTest(CoverageTest):
                 a -= 1
             assert a == 0 and b == 3
             """,
-            [1,2,5,6,7], ""
+            [1,2,5,6,7], "",
         )
 
     def test_for(self) -> None:
@@ -1062,7 +1042,7 @@ class CompoundStatementTest(CoverageTest):
                 a += i
             assert a == 15
             """,
-            [1,2,3,4], ""
+            [1,2,3,4], "",
         )
         self.check_coverage("""\
             a = 0
@@ -1072,7 +1052,7 @@ class CompoundStatementTest(CoverageTest):
                 a += i
             assert a == 15
             """,
-            [1,2,5,6], ""
+            [1,2,5,6], "",
         )
         self.check_coverage("""\
             a = 0
@@ -1081,7 +1061,7 @@ class CompoundStatementTest(CoverageTest):
                 break
             assert a == 1
             """,
-            [1,2,3,4,5], ""
+            [1,2,3,4,5], "",
         )
 
     def test_for_else(self) -> None:
@@ -1093,7 +1073,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 99
             assert a == 99
             """,
-            [1,2,3,5,6], ""
+            [1,2,3,5,6], "",
         )
         self.check_coverage("""\
             a = 0
@@ -1104,7 +1084,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 123
             assert a == 1
             """,
-            [1,2,3,4,6,7], "6"
+            [1,2,3,4,6,7], "6",
         )
 
     def test_split_for(self) -> None:
@@ -1115,7 +1095,7 @@ class CompoundStatementTest(CoverageTest):
                 a += i
             assert a == 15
             """,
-            [1,2,4,5], ""
+            [1,2,4,5], "",
         )
         self.check_coverage("""\
             a = 0
@@ -1126,7 +1106,7 @@ class CompoundStatementTest(CoverageTest):
                 a += i
             assert a == 15
             """,
-            [1,2,6,7], ""
+            [1,2,6,7], "",
         )
 
     def test_try_except(self) -> None:
@@ -1138,7 +1118,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 99
             assert a == 1
             """,
-            [1,2,3,4,5,6], "4-5"
+            [1,2,3,4,5,6], "4-5",
         )
         self.check_coverage("""\
             a = 0
@@ -1149,7 +1129,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 99
             assert a == 99
             """,
-            [1,2,3,4,5,6,7], ""
+            [1,2,3,4,5,6,7], "",
         )
         self.check_coverage("""\
             a = 0
@@ -1162,7 +1142,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 123
             assert a == 123
             """,
-            [1,2,3,4,5,6,7,8,9], "6"
+            [1,2,3,4,5,6,7,8,9], "6",
         )
         self.check_coverage("""\
             a = 0
@@ -1177,7 +1157,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 123
             assert a == 17
             """,
-            [1,2,3,4,5,6,7,8,9,10,11], "6, 9-10"
+            [1,2,3,4,5,6,7,8,9,10,11], "6, 9-10",
         )
         self.check_coverage("""\
             a = 0
@@ -1190,8 +1170,7 @@ class CompoundStatementTest(CoverageTest):
             assert a == 123
             """,
             [1,2,3,4,5,7,8], "4-5",
-            arcz=".1 12 23 45 58 37 78 8.",
-            arcz_missing="45 58",
+            branchz="", branchz_missing="",
         )
 
     def test_try_except_stranded_else(self) -> None:
@@ -1199,13 +1178,9 @@ class CompoundStatementTest(CoverageTest):
             # The else can't be reached because the try ends with a raise.
             lines = [1,2,3,4,5,6,9]
             missing = ""
-            arcz = ".1 12 23 34 45 56 69 9."
-            arcz_missing = ""
         else:
             lines = [1,2,3,4,5,6,8,9]
             missing = "8"
-            arcz = ".1 12 23 34 45 56 69 89 9."
-            arcz_missing = "89"
         self.check_coverage("""\
             a = 0
             try:
@@ -1219,8 +1194,7 @@ class CompoundStatementTest(CoverageTest):
             """,
             lines=lines,
             missing=missing,
-            arcz=arcz,
-            arcz_missing=arcz_missing,
+            branchz="", branchz_missing="",
         )
 
     def test_try_finally(self) -> None:
@@ -1232,7 +1206,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 99
             assert a == 99
             """,
-            [1,2,3,5,6], ""
+            [1,2,3,5,6], "",
         )
         self.check_coverage("""\
             a = 0; b = 0
@@ -1246,7 +1220,7 @@ class CompoundStatementTest(CoverageTest):
                 a = 99
             assert a == 99 and b == 123
             """,
-            [1,2,3,4,5,7,8,9,10], ""
+            [1,2,3,4,5,7,8,9,10], "",
         )
 
     def test_function_def(self) -> None:
@@ -1260,7 +1234,7 @@ class CompoundStatementTest(CoverageTest):
             a = foo()
             assert a == 1
             """,
-            [1,2,5,7,8], ""
+            [1,2,5,7,8], "",
         )
         self.check_coverage("""\
             def foo(
@@ -1274,7 +1248,7 @@ class CompoundStatementTest(CoverageTest):
             x = foo(17, 23)
             assert x == 40
             """,
-            [1,7,9,10], ""
+            [1,7,9,10], "",
         )
         self.check_coverage("""\
             def foo(
@@ -1291,11 +1265,10 @@ class CompoundStatementTest(CoverageTest):
             x = foo()
             assert x == 22
             """,
-            [1,10,12,13], ""
+            [1,10,12,13], "",
         )
 
     def test_class_def(self) -> None:
-        arcz="-22 2D DE E-2  23 36 6A A-2  -68 8-6   -AB B-A"
         self.check_coverage("""\
             # A comment.
             class theClass:
@@ -1313,7 +1286,7 @@ class CompoundStatementTest(CoverageTest):
             assert x == 1
             """,
             [2, 6, 8, 10, 11, 13, 14], "",
-            arcz=arcz,
+            branchz="", branchz_missing="",
         )
 
 
@@ -1331,7 +1304,7 @@ class ExcludeTest(CoverageTest):
             f = 6#\tpragma:\tno cover
             g = 7
             """,
-            [1,3,5,7]
+            [1,3,5,7],
         )
 
     def test_two_excludes(self) -> None:
@@ -1344,7 +1317,7 @@ class ExcludeTest(CoverageTest):
                 c = 6   # -xx
             assert a == 1 and b == 2
             """,
-            [1,3,5,7], "5", excludes=['-cc', '-xx']
+            [1,3,5,7], "5", excludes=['-cc', '-xx'],
         )
 
     def test_excluding_elif_suites(self) -> None:
@@ -1363,7 +1336,7 @@ class ExcludeTest(CoverageTest):
                 b = 12
             assert a == 4 and b == 5 and c == 6
             """,
-            [1,3,4,5,6,11,12,13], "11-12", excludes=['#pragma: NO COVER']
+            [1,3,4,5,6,11,12,13], "11-12", excludes=['#pragma: NO COVER'],
         )
 
     def test_excluding_try_except(self) -> None:
@@ -1378,18 +1351,10 @@ class ExcludeTest(CoverageTest):
             assert a == 123
             """,
             [1,2,3,7,8], "", excludes=['#pragma: NO COVER'],
-            arcz=".1 12 23 37 45 58 78 8.",
-            arcz_missing="58",
+            branchz="", branchz_missing="",
         )
 
     def test_excluding_try_except_stranded_else(self) -> None:
-        if env.PYBEHAVIOR.optimize_unreachable_try_else:
-            # The else can't be reached because the try ends with a raise.
-            arcz = ".1 12 23 34 45 56 69 9."
-            arcz_missing = ""
-        else:
-            arcz = ".1 12 23 34 45 56 69 89 9."
-            arcz_missing = "89"
         self.check_coverage("""\
             a = 0
             try:
@@ -1402,8 +1367,7 @@ class ExcludeTest(CoverageTest):
             assert a == 99
             """,
             [1,2,3,4,5,6,9], "", excludes=['#pragma: NO COVER'],
-            arcz=arcz,
-            arcz_missing=arcz_missing,
+            branchz="", branchz_missing="",
         )
 
     def test_excluded_comprehension_branches(self) -> None:
@@ -1416,8 +1380,8 @@ class ExcludeTest(CoverageTest):
                 raise NotImplementedError   # pragma: NO COVER
             """,
             [1,2,4], "", excludes=['#pragma: NO COVER'],
-            arcz=".1 12 23 24 45 4.  -44 4-4",
-            arcz_missing="4-4",
+            branchz="23 24 45 4.",
+            branchz_missing="",
         )
 
 
@@ -1440,7 +1404,7 @@ class Py24Test(CoverageTest):
 
             assert p1(10) == 20
             """,
-            lines, ""
+            lines, "",
         )
 
     def test_function_decorators_with_args(self) -> None:
@@ -1459,7 +1423,7 @@ class Py24Test(CoverageTest):
 
             assert boosted(10) == 200
             """,
-            lines, ""
+            lines, "",
         )
 
     def test_double_function_decorators(self) -> None:
@@ -1492,7 +1456,7 @@ class Py24Test(CoverageTest):
 
             assert boosted2(10) == 200
             """,
-            lines, ""
+            lines, "",
         )
 
 
@@ -1520,7 +1484,7 @@ class Py25Test(CoverageTest):
             except:
                 desc = "caught"
             """,
-            [1,2,3,5,6,8,9,10,11,13,14,15,16,17,18], ""
+            [1,2,3,5,6,8,9,10,11,13,14,15,16,17,18], "",
         )
 
     def test_try_except_finally(self) -> None:
@@ -1535,7 +1499,7 @@ class Py25Test(CoverageTest):
             assert a == 1 and b == 2
             """,
             [1,2,3,4,5,7,8], "4-5",
-            arcz=".1 12 23 37 45 57 78 8.", arcz_missing="45 57",
+            branchz="", branchz_missing="",
         )
         self.check_coverage("""\
             a = 0; b = 0
@@ -1549,7 +1513,7 @@ class Py25Test(CoverageTest):
             assert a == 99 and b == 2
             """,
             [1,2,3,4,5,6,8,9], "",
-            arcz=".1 12 23 34 45 56 68 89 9.",
+            branchz="", branchz_missing="",
         )
         self.check_coverage("""\
             a = 0; b = 0
@@ -1565,7 +1529,7 @@ class Py25Test(CoverageTest):
             assert a == 123 and b == 2
             """,
             [1,2,3,4,5,6,7,8,10,11], "6",
-            arcz=".1 12 23 34 45 56 57 78 6A 8A AB B.", arcz_missing="56 6A",
+            branchz="", branchz_missing="",
         )
         self.check_coverage("""\
             a = 0; b = 0
@@ -1583,8 +1547,7 @@ class Py25Test(CoverageTest):
             assert a == 17 and b == 2
             """,
             [1,2,3,4,5,6,7,8,9,10,12,13], "6, 9-10",
-            arcz=".1 12 23 34 45 56 6C 57 78 8C 79 9A AC CD D.",
-            arcz_missing="56 6C 79 9A AC",
+            branchz="", branchz_missing="",
         )
         self.check_coverage("""\
             a = 0; b = 0
@@ -1599,8 +1562,7 @@ class Py25Test(CoverageTest):
             assert a == 123 and b == 2
             """,
             [1,2,3,4,5,7,9,10], "4-5",
-            arcz=".1 12 23 37 45 59 79 9A A.",
-            arcz_missing="45 59",
+            branchz="", branchz_missing="",
         )
 
     def test_try_except_finally_stranded_else(self) -> None:
@@ -1608,13 +1570,9 @@ class Py25Test(CoverageTest):
             # The else can't be reached because the try ends with a raise.
             lines = [1,2,3,4,5,6,10,11]
             missing = ""
-            arcz = ".1 12 23 34 45 56 6A AB B."
-            arcz_missing = ""
         else:
             lines = [1,2,3,4,5,6,8,10,11]
             missing = "8"
-            arcz = ".1 12 23 34 45 56 6A 8A AB B."
-            arcz_missing = "8A"
         self.check_coverage("""\
             a = 0; b = 0
             try:
@@ -1630,8 +1588,7 @@ class Py25Test(CoverageTest):
             """,
             lines=lines,
             missing=missing,
-            arcz=arcz,
-            arcz_missing=arcz_missing,
+            branchz="", branchz_missing="",
         )
 
 
